"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBridges = exports.buildAccountBridge = exports.buildCurrencyBridge = void 0;
const jsHelpers_1 = require("@ledgerhq/coin-framework/bridge/jsHelpers");
const getAddressWrapper_1 = __importDefault(require("@ledgerhq/coin-framework/bridge/getAddressWrapper"));
const estimateMaxSpendable_1 = require("../estimateMaxSpendable");
const formatters_1 = __importDefault(require("../formatters"));
const getTransactionStatus_1 = require("../getTransactionStatus");
const synchronization_1 = require("../synchronization");
const prepareTransaction_1 = require("../prepareTransaction");
const createTransaction_1 = require("../createTransaction");
const signOperation_1 = require("../signOperation");
const initAccount_1 = require("../initAccount");
const broadcast_1 = require("../broadcast");
const hw_getAddress_1 = __importDefault(require("../hw-getAddress"));
const serialization_1 = require("../serialization");
function buildCurrencyBridge(signerContext) {
    const getAddress = (0, hw_getAddress_1.default)(signerContext);
    const scanAccounts = (0, jsHelpers_1.makeScanAccounts)({
        getAccountShape: synchronization_1.getAccountShape,
        getAddressFn: getAddress,
    });
    return {
        preload: async () => Promise.resolve({}),
        hydrate: () => { },
        scanAccounts,
    };
}
exports.buildCurrencyBridge = buildCurrencyBridge;
function buildAccountBridge(signerContext) {
    const getAddress = (0, hw_getAddress_1.default)(signerContext);
    const receive = (0, jsHelpers_1.makeAccountBridgeReceive)((0, getAddressWrapper_1.default)(getAddress));
    const signOperation = (0, signOperation_1.buildSignOperation)(signerContext);
    return {
        createTransaction: createTransaction_1.createTransaction,
        updateTransaction: jsHelpers_1.updateTransaction,
        prepareTransaction: prepareTransaction_1.prepareTransaction,
        getTransactionStatus: getTransactionStatus_1.getTransactionStatus,
        sync: synchronization_1.sync,
        receive,
        assignToAccountRaw: serialization_1.assignToAccountRaw,
        assignFromAccountRaw: serialization_1.assignFromAccountRaw,
        initAccount: initAccount_1.initAccount,
        signOperation,
        broadcast: broadcast_1.broadcast,
        estimateMaxSpendable: estimateMaxSpendable_1.estimateMaxSpendable,
        fromOperationExtraRaw: serialization_1.fromOperationExtraRaw,
        toOperationExtraRaw: serialization_1.toOperationExtraRaw,
        formatAccountSpecifics: formatters_1.default.formatAccountSpecifics,
        formatOperationSpecifics: formatters_1.default.formatOperationSpecifics,
        getSerializedAddressParameters: jsHelpers_1.getSerializedAddressParameters,
    };
}
exports.buildAccountBridge = buildAccountBridge;
function createBridges(signerContext) {
    return {
        currencyBridge: buildCurrencyBridge(signerContext),
        accountBridge: buildAccountBridge(signerContext),
    };
}
exports.createBridges = createBridges;
//# sourceMappingURL=js.js.map