import type { Account, AccountRaw, Operation, OperationExtra, OperationExtraRaw, OperationRaw, TransactionCommon, TransactionCommonRaw, TransactionStatusCommon, TransactionStatusCommonRaw } from "@ledgerhq/types-live";
import type { BigNumber } from "bignumber.js";
export declare const AlgorandOperationTypeEnum: {
    PAYMENT: number;
    ASSET_OPT_IN: number;
    ASSET_OPT_OUT: number;
    ASSET_TRANSFER: number;
};
export type AlgorandResources = {
    rewards: BigNumber;
    nbAssets: number;
};
export type AlgorandResourcesRaw = {
    rewards: string;
    nbAssets: number;
};
export type AlgorandOperationMode = "send" | "optIn" | "claimReward";
export type AlgorandTransaction = TransactionCommon & {
    family: "algorand";
    mode: AlgorandOperationMode;
    fees: BigNumber | null | undefined;
    assetId: string | null | undefined;
    memo: string | null | undefined;
};
export type AlgorandTransactionRaw = TransactionCommonRaw & {
    family: "algorand";
    mode: AlgorandOperationMode;
    fees: string | null | undefined;
    assetId: string | null | undefined;
    memo: string | null | undefined;
};
export type TransactionStatus = TransactionStatusCommon;
export type TransactionStatusRaw = TransactionStatusCommonRaw;
export type Transaction = AlgorandTransaction;
export type TransactionRaw = AlgorandTransactionRaw;
export type AlgorandOperation = Operation<AlgorandOperationExtra>;
export type AlgorandOperationRaw = OperationRaw<AlgorandOperationExtraRaw>;
export type AlgorandOperationExtra = {
    rewards?: BigNumber | undefined;
    memo?: string | undefined;
    assetId?: string | undefined;
};
export declare function isAlgorandOperationExtra(op: OperationExtra): op is AlgorandOperationExtra;
export type AlgorandOperationExtraRaw = {
    rewards?: string | undefined;
    memo?: string | undefined;
    assetId?: string | undefined;
};
export declare function isAlgorandOperationExtraRaw(op: OperationExtraRaw): op is AlgorandOperationExtraRaw;
export type AlgorandAccount = Account & {
    algorandResources: AlgorandResources;
};
export type AlgorandAccountRaw = AccountRaw & {
    algorandResources: AlgorandResourcesRaw;
};
//# sourceMappingURL=types.d.ts.map